# -*- coding: utf-8
from django.apps import AppConfig


class PlansPaymentsConfig(AppConfig):
    name = "plans_payments"
